/****************************************************************************
image_io.h - Prototypes for image input/output functions

Author:  Paul Hughett

Copyright (c) 1998-2000 Trustees of the University of Pennsylvania
See the file COPYING for license terms.

This public header file contains prototypes for various image input/output
functions used within bblimage.

****************************************************************************/

#ifndef IMAGE_IO_H
#define IMAGE_IO_H

/* Including the following two header files here excites a SunOS bug??? */

#include <stdio.h>           /* For FILE and friends */
#include <stdlib.h>          /* For size_t and friends */

extern int sizeof_ImgType(int type);

extern float ** alloc_img (int N, int M);
extern unsigned char **alloc_char (int N, int M);
extern double **alloc_imgdouble (int N, int M);
extern float ***alloc_3Dimg (int N, int M, int K);
extern unsigned char ***alloc_3Dchar (int N, int M, int K);

extern void free_img(float **ImageP);
extern void free_char(unsigned char **ImageP);
extern void free_imgdouble( double ** ImageP );
extern void free_3Dimg(float ***ImageP, int K);
extern void free_3Dchar(unsigned char ***ImageP, int K);

extern FILE *open_file(const char *FileName, const char *OpenType);
extern void read_matrix (FILE *FileP, float **ImageP, int N, int M,
    int ImgType);
extern void get_matrix (char *FileName, float **ImageP, int N, int M,
    int ImgType);
extern void write_matrix (FILE *FileP, float**ImageP, int N, int M,
    int ImgType);
extern void put_matrix (char *FileName, float **ImageP, int N, int M,
    int ImgType);
extern void put_volume_uchar(char * FileName, unsigned char ***ImageP,
    int N, int M, int L);
extern void copy_matrix (float **InImgP, float **OutImgP, int N, int M);
extern void copy_char (unsigned char **Label_In, unsigned char **Label_Out, 
    int N, int M);


#endif /* IMAGE_IO_H */
