/*---------------------------------------------------------------
definition.h - Def ine some commonly used constants and macros

Author:  Michelle Yan

Copyright (c) 1998 Trustees of the University of Pennsylvania
See the file COPYING for license terms.
---------------------------------------------------------------*/

#ifndef DEFINITION
#define DEFINITION

#define FALSE   0
#define TRUE    1

#define UNKNOWN          0

#ifndef PI
#define PI           3.141592654
#endif

/* Use the following to surpress gcc warnings that a variable might
   be used uninitialized without really checking the code to see that
   this is okay.  Used only on code debugged by other people.  PWH */
#define NOT_UNINIT     0

/* Some standard pixel labels in a binary [sic] image.  Note that changing
   these values is likely to have disastrous side-effects. */
#define BACKGROUND     0
#define BOUNDARY     175
#define OBJECT       255

#define HISTO_L            256
#define HISTO_BACKGROUND   200
#define HISTO_VALUE        50

#define COVMATRIX_L      3

#define TINY_VALUE       1.0e-25
#define INFINITE         1.0e25
#define ZERO             1.0e-25

#define UNDEFINED       -1

#define CROSSCOV_L       3
#define SVDMATRIX_L      4
#define Q_L              7

/******
Despite what you might expect, the following symbols describe the
external representation of image data stored in a file.  They are
relics of the Sun architecture, where the correspondence between
C types and external representation is as shown.  All the external
representations listed here are big endian, even on little endian
machines; this is to facilitate file interchange.  FIXME: Floats 
should not be expected to work correctly on other than Suns; the 
smallest negative value for signed types should not be expected 
to work on other than 2's complement machines.  New code should NOT
exploit the fact that the size of a type is equal to the absolute
value of the type name, since this may change in the future.
******/
#define UNSIGNED_CHAR    1       /* Unsigned 1-byte integers */
#define UNSIGNED_SHORT   2       /* Unsigned 2-byte integers */
#define SHORT           -2       /* Signed 2-type integers */
#define INT              4       /* Signed 4-byte integers */
#define FLOAT           -4       /* 4-byte floats, Sun format */

/* Improved names for new, portable code */
#define UCHAR            1       /* Unsigned 1-byte integers */
#define UINT2            2       /* Unsigned 2-byte integers */
#define INT2            -2       /* Signed 2-byte integers */
#define INT4             4       /* Signed 4-byte integers */
#define FLOAT4          -4       /* 4-byte floats, Sun format */


/* Filter type specifications for the function smoothing in image_inc.c */
#define NOSMOOTH         0
#define AVERAGE3X3       1
#define GAUSSIAN3X3      2
#define AVERAGE5X5       3
#define GAUSSIAN5X5      4
#define GAUSSIAN7X7      5

/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
/* Structure for 2D coordinates                                             */
/*--------------------------------------------------------------------------*/
struct coordinate2 {
    int i, j;                    /* coordinate of (i,j).                    */
};

/*--------------------------------------------------------------------------*/
/* Structure for Cross/Covariance matrix info                               */
/*--------------------------------------------------------------------------*/
typedef struct {
    float       XY_Resolution;    /* Pixel size of X- and Y-directoin       */
    float       Z_Resolution;     /* Pixel size of Z-direction              */
    float       XY_Resolution_BS; /* Pixel size of X, Y-directoin of other  */
                                  /* set                                    */
    float       Z_Resolution_BS;  /* Pixel size of Z-direction of other set */

    float       ImgCenter[3];     /* Defined as half of Rows, cols & slices */
    float       ImgCenter_BS[3];  /* Image center of other set              */
	
    double      *Mean;            /* 3 components of center of mass         */
    double      *Mean_BS;         /* Center of mass of other set            */

    double      **Cov;            /* 3X3 covariance matrix                  */

    int         Total_ObjSize;    /* Total (corresponding) points           */
}  CovMatrix_Info;

/*--------------------------------------------------------------------------*/
/* Structure for a transform info                                           */
/*--------------------------------------------------------------------------*/
typedef struct {
    double      alpha_x, alpha_y, /* Angles must be in radian.              */
                alpha_z;

    double      cos_alpha_z, sin_alpha_z;
    double      cos_alpha_y, sin_alpha_y;
    double      cos_alpha_x, sin_alpha_x;

    double      Translation_x,    /* Translation vector                     */
                Translation_y,
                Translation_z;
    double      **Rotation;       /* Rotation matrix constructed by rotating*/
                                  /* about z-, y- and x-axis respectively   */
}  Transform_Info;

/*--------------------------------------------------------------------------*/
/* Structure for a K_Mean (ML or MAP) info                                  */
/*--------------------------------------------------------------------------*/
typedef struct {  
    float  Total_Mean;
    float  *K_Mean;               /* Array for means of K-region            */
    double *Kmean_Sum;            /* Centers of each region                 */
    int    *Kmean_Count;          /* Number of points of each region        */
} Kmean_Info;

#endif
